==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebDateFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseDateTimeFilteringOperandDescriptionMetadata } from "./WebBaseDateTimeFilteringOperandDescriptionMetadata";
import { WebDateFilteringOperandDescription } from "./WebDateFilteringOperandDescription";
/**
 * @hidden
 */
export let WebDateFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDateFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebDateFilteringOperandDescriptionMetadata.a == null) {
                WebDateFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDateFilteringOperandDescriptionMetadata.c(WebDateFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebDateFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebDateFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseDateTimeFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:DateFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebDateFilteringOperandDescriptionMetadata.b(a);
            a.ad("WebDateFilteringOperand", () => new WebDateFilteringOperandDescription());
            a.ac("WebDateFilteringOperand", WebDateFilteringOperandDescriptionMetadata.a);
        }
    }
    WebDateFilteringOperandDescriptionMetadata.$t = markType(WebDateFilteringOperandDescriptionMetadata, 'WebDateFilteringOperandDescriptionMetadata');
    WebDateFilteringOperandDescriptionMetadata.a = null;
    return WebDateFilteringOperandDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebDateFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseDateTimeFilteringOperandDescriptionMetadata } from "./WebBaseDateTimeFilteringOperandDescriptionMetadata";
import { WebDateFilteringOperandDescription } from "./WebDateFilteringOperandDescription";
/**
 * @hidden
 */
export let WebDateFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDateFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebDateFilteringOperandDescriptionMetadata.a == null) {
                WebDateFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDateFilteringOperandDescriptionMetadata.c(WebDateFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebDateFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebDateFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseDateTimeFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:DateFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebDateFilteringOperandDescriptionMetadata.b(a);
            a.ae("WebDateFilteringOperand", () => new WebDateFilteringOperandDescription());
            a.ad("WebDateFilteringOperand", WebDateFilteringOperandDescriptionMetadata.a);
        }
    }
    WebDateFilteringOperandDescriptionMetadata.$t = markType(WebDateFilteringOperandDescriptionMetadata, 'WebDateFilteringOperandDescriptionMetadata');
    WebDateFilteringOperandDescriptionMetadata.a = null;
    return WebDateFilteringOperandDescriptionMetadata;
})();
